*****************************************************************************************
* FILE NAME:     SASOUT22_LLCP.SAS                                                      *
* DESCRIPTION:   THIS PROGRAM CONVERTS A STATES ASCII DATAFILE OF COMPLETES LOCATED AT  *
*                <DATAIN> FILEREF, INTO A SAS DATABASE STORED AT <DATAOUT> LIBREF       *
* REFERENCES:                                                                           *
* INPUT       DATAIN           FILEREF OF ASCII DATAFILE OF COMPLETES                   *
* FORMATS     FORMATS.SAS7BCAT      SAS FORMATS DATABASE                                *
* OUTPUT      DATAOUT.SASDATA  SAS DATABASE VERSION OF ASCII DATA AS SPECIFIED IN       *
*                              <DATAIN> FILEREF                                         *
* UPDATED - 07/07/2023                                                                  *
*****************************************************************************************;
********************************
* Clear Output and Log Windows *
********************************;
DM OUTPUT 'clear' continue;
DM LOG    'clear' continue;
**********************************
* DEFINE SAS ENVIRONMENT OPTIONS *
**********************************;
OPTIONS PAGENO=1 NOFMTERR;
***************************************
* CLEAR EXISTING TITLES AND FOOTNOTES *
***************************************;
TITLE ;
FOOTNOTE ;
RUN ;
******************************************************************
* INSTRUCTIONS:                                                  *
* SPECIFY PATH OF WHERE ASCII DATAFILE IS STORED                 *
* SPECIFY PATH OF WHERE SAS DATASET IS TO BE STORED              *
* SPECIFY PATH OF WHERE SAS FORMAT LIBRARY IS STORED             *
* SPECIFY PATH OF WHERE THE FORMAT ASSIGNMET STATEMENT IS STORED *
******************************************************************;

*FILENAME DATAIN '<PATH OF INPUT STATE ASCII DATAFILE OF COMPLETES>' LRECL = 2052 ;
*****************************************************************************
* EXAMPLE:                                                                  *
*       FILENAME DATAIN 'C:\BRFSS\2022\LLCP2022.ASC' LRECL = 2052           *
* NOTE: MAKE SURE THE ASTERISK IS REMOVED BEFORE THE WORD FILENAME AND      *
*       MAKE SURE THAT THE GREATER THAN AND LESS THAN SIGNS < > ARE REMOVED *
*       FROM THE FILENAME STATEMENT                                         *
*****************************************************************************;

*LIBNAME DATAOUT V7 '<PATH OF PERMANENTLY STORED SAS DATASET VERSION OF DATAIN FILEREF>'  ;
*****************************************************************************
* EXAMPLE:                                                                  *
*          LIBNAME DATAOUT 'C:\'                                            *
*          A SAS DATABASE WILL BE STORED AT C:\SASDATA.sas7bdat             *
* NOTE: MAKE SURE THE ASTERISK IS REMOVED BEFORE THE WORD LIBNAME AND       *
*       MAKE SURE THAT THE GREATER THAN AND LESS THAN SIGNS < > ARE REMOVED *
*       FROM THE LIBNAME STATEMENT                                          *
*****************************************************************************;

*LIBNAME LIBRARY '<PATH OF STORED SAS FORMAT22.SAS7BCAT>' ;
*****************************************************************************
* EXAMPLE:                                                                  *
*          LIBNAME LIBRARY 'C:\'                                            *
* NOTE: MAKE SURE THE ASTERISK IS REMOVED BEFORE THE WORD LIBNAME AND       *
*       MAKE SURE THAT THE GREATER THAN AND LESS THAN SIGNS < > ARE REMOVED *
*       FROM THE LIBNAME STATEMENT                                          *
*****************************************************************************;

*FILENAME FORMATIN '<PATH OF FORMAT ASSIGNMENT STATEMENT>' ;
*****************************************************************************
* EXAMPLE:                                                                  *
*          FILENAME FORMATIN 'C:\FORMATSTATEMENT.SAS'                       *
* NOTE: MAKE SURE THE ASTERISK IS REMOVED BEFORE THE WORD FILENAME AND      *
*       MAKE SURE THAT THE GREATER THAN AND LESS THAN SIGNS < > ARE REMOVED *
*       FROM THE FILENAME STATEMENT                                         *
*****************************************************************************;

DATA DATAOUT.SASDATA ;
INFILE DATAIN MISSOVER ;
INPUT
_STATE        1-2                     /* Record Identification */
FMONTH        17-18
IDATE         $19-26
IMONTH        $19-20
IDAY          $21-22
IYEAR         $23-26
DISPCODE      32-35
SEQNO         $36-45
_PSU          36-45
CTELENM1      63                      /* Land Line Introduction */
PVTRESD1      64
COLGHOUS      65
STATERE1      66
CELPHON1      67
LADULT1       68
COLGSEX1      69
NUMADULT      70-71
LANDSEX1      72
NUMMEN        73-74
NUMWOMEN      75-76
RESPSLCT      77
SAFETIME      78                      /* Cell Phone Introduction */
CTELNUM1      79
CELLFON5      80
CADULT1       81
CELLSEX1      82
PVTRESD3      83
CCLGHOUS      84
CSTATE1       85
LANDLINE      88
HHADULT       89-90
SEXVAR        91                      /* Respondent Sex */
GENHLTH       101                     /* Section 1: Health Status */
PHYSHLTH      102-103                 /* Section 2: Healthy Days */
MENTHLTH      104-105
POORHLTH      106-107
PRIMINSR      108-109                 /* Section 3: Health Care Access */
PERSDOC3      110
MEDCOST1      111
CHECKUP1      112
EXERANY2      113                     /* Section 4: Exercise */
SLEPTIM1      114-115                 /* Section 5: Inadequate Sleep */
LASTDEN4      116                     /* Section 6: Oral Health */
RMVTETH4      117
CVDINFR4      118                     /* Section 7: Chronic Health Conditions */
CVDCRHD4      119
CVDSTRK3      120
ASTHMA3       121
ASTHNOW       122
CHCSCNC1      123
CHCOCNC1      124
CHCCOPD3      125
ADDEPEV3      126
CHCKDNY2      127
HAVARTH4      128
DIABETE4      129
DIABAGE4      130-131
MARITAL       168
EDUCA         169
RENTHOM1      170
NUMHHOL4      179
NUMPHON4      180
CPDEMO1C      181
VETERAN3      182
EMPLOY1       183
CHILDREN      184-185
INCOME3       186-187
PREGNANT      188
WEIGHT2       189-192
HEIGHT3       193-196
DEAF          197                     /* Section 9: Disability */
BLIND         198
DECIDE        199
DIFFWALK      200
DIFFDRES      201
DIFFALON      202
HADMAM        203                     /* Section 10: Breast and Cervical Cancer Screening */
HOWLONG       204
CERVSCRN      205
CRVCLCNC      206
CRVCLPAP      207
CRVCLHPV      208
HADHYST2      209
HADSIGM4      210                     /* Section 11: Colorectal Cancer Screening */
COLNSIGM      211
COLNTES1      212
SIGMTES1      213
LASTSIG4      214
COLNCNCR      215
VIRCOLO1      216
VCLNTES2      217
SMALSTOL      218
STOLTEST      219
STOOLDN2      220
BLDSTFIT      221
SDNATES1      222
SMOKE100      223                     /* Section 12: Tobacco Use */
SMOKDAY2      224
USENOW3       225
ECIGNOW2      226
LCSFIRST      227-229                 /* Section 13: Lung Cancer Screening */
LCSLAST       230-232
LCSNUMCG      233-235
LCSCTSC1      236
LCSSCNCR      237
LCSCTWHN      238
ALCDAY4       239-241                 /* Section 14: Alcohol Consumption */
AVEDRNK3      242-243
DRNK3GE5      244-245
MAXDRNKS      246-247
FLUSHOT7      248                     /* Section 15: Immunization */
FLSHTMY3      249-254
PNEUVAC4      255
TETANUS1      256
HIVTST7       257                     /* Section 16: HIV/AIDS */
HIVTSTD3      258-263
HIVRISK5      264
COVIDPOS      265                     /* Section 17: Long-term COVID Effects */
COVIDSMP      266
COVIDPRM      267-268
PDIABTS1      269                     /* Module 1: Pre-Diabetes */
PREDIAB2      270
DIABTYPE      271                     /* Module 2: Diabetes */
INSULIN1      272
CHKHEMO3      273-274
EYEEXAM1      275
DIABEYE1      276
DIABEDU1      277
FEETSORE      278
TOLDCFS       279                     /* Module 3: ME/CFS */
HAVECFS       280
WORKCFS       281
IMFVPLA3      282-283                 /* Module 4: Place of Flu Vaccination */
HPVADVC4      284                     /* Module 5: HPV Vaccination */
HPVADSHT      285-286
SHINGLE2      287                     /* Module 6: Shingles Vaccination */
COVIDVA1      288                     /* Module 7: COVID Vaccination */
COVIDNU1      290
COVIDFS1      292-297
COVIDSE1      298-303
COPDCOGH      304                     /* Module 8: Respiratory Health */
COPDFLEM      305
COPDBRTH      306
COPDBTST      307
COPDSMOK      308-309
CNCRDIFF      310                     /* Module 9: Cancer Survivorship: Type of Cancer */
CNCRAGE       311-312
CNCRTYP2      313-314
CSRVTRT3      315                     /* Module 10: Cancer Survivorship: Course of Treatment */
CSRVDOC1      316-317
CSRVSUM       318
CSRVRTRN      319
CSRVINST      320
CSRVINSR      321
CSRVDEIN      322
CSRVCLIN      323
CSRVPAIN      324                     /* Module 11: Cancer Survivorship: Pain Management */
CSRVCTL2      325
PSATEST1      326                     /* Module 12: Prostate Cancer Screening */
PSATIME1      327
PCPSARS2      328
PSASUGST      329
PCSTALK1      330
CIMEMLOS      331                     /* Module 13: Cognitive Decline */
CDHOUSE       332
CDASSIST      333
CDHELP        334
CDSOCIAL      335
CDDISCUS      336
CAREGIV1      337                     /* Module 14: Caregiver */
CRGVREL4      338-339
CRGVLNG1      340
CRGVHRS1      341
CRGVPRB3      342-343
CRGVALZD      344
CRGVPER1      345
CRGVHOU1      346
CRGVEXPT      347
ACEDEPRS      348                     /* Module 15: Adverse Childhood Experiences */
ACEDRINK      349
ACEDRUGS      350
ACEPRISN      351
ACEDIVRC      352
ACEPUNCH      353
ACEHURT1      354
ACESWEAR      355
ACETOUCH      356
ACETTHEM      357
ACEHVSEX      358
ACEADSAF      359
ACEADNED      360
LSATISFY      361                     /* Module 16: Social Determinants and Health Equity */
EMTSUPRT      362
SDHISOLT      363
SDHEMPLY      364
FOODSTMP      365
SDHFOOD1      366
SDHBILLS      367
SDHUTILS      368
SDHTRNSP      369
SDHSTRE1      370
MARIJAN1      371-372                 /* Module 17: Marijuana Use */
MARJSMOK      373
MARJEAT       374
MARJVAPE      375
MARJDAB       376
MARJOTHR      377
USEMRJN4      378
LASTSMK2      379-380                 /* Module 18: Tobacco Cessation */
STOPSMK2      381
MENTCIGS      382                     /* Module 19: Other Tobacco Use */
MENTECIG      383
HEATTBCO      384
ASBIALCH      385                     /* Module 20: Alcohol Screening & Brief Intervention (ASBI) */
ASBIDRNK      386
ASBIBING      387
ASBIADVC      388
ASBIRDUC      389
FIREARM5      390                     /* Module 21: Firearm Safety */
GUNLOAD       391
LOADULK2      392
RCSGEND1      599
RCSXBRTH      600
RCSRLTN2      635
CASTHDX2      636                     /* Module 24: Childhood Asthma Prevalence */
CASTHNO2      637
BIRTHSEX      638                     /* Module 25: Sex at Birth */
SOMALE        639
SOFEMALE      640
TRNSGNDR      641
HADSEX        642                     /* Module 27: Family Planning */
PFPPRVN4      643
TYPCNTR9      644-645
BRTHCNT4      646-647
WHEREGET      648-649
NOBCUSE8      650-651
BCPREFER      652-653
RRCLASS3      654-655                 /* Module 28: Reactions to Race */
RRCOGNT2      656
RRTREAT       657
RRATWRK2      658
RRHCARE4      659
RRPHYSM2      660
QSTVER        665-666                 /* Questionnaire Version */
QSTLANG       667-668                 /* Questionnaire Language */
_METSTAT      1402
_URBSTAT      1403
MSCODE        1409
_STSTR        1410-1415
_STRWT        1416-1425
_RAWRAKE      1446-1455
_WT2RAKE      1456-1465
_IMPRACE      1471-1472
_CHISPNC      1482                    /* Child Demographic Variables */
_CRACE2       1539-1540
_CPRACE2      1541-1542
CAGEG         1569
_CLLCPWT      1585-1594
_DUALUSE      1682
_DUALCOR      1683-1692
_LLCPWT2      1693-1702
_LLCPWT       1751-1760
_RFHLTH       1899                    /* Section 1: Calculated Variables */
_PHYS14D      1900                    /* Section 2: Calculated Variables */
_MENT14D      1901
_HLTHPLN      1902                    /* Section 3: Calculated Variables */
_HCVU652      1903
_TOTINDA      1904                    /* Section 4: Calculated Variables */
_EXTETH3      1905                    /* Section 6: Calculated Variables */
_ALTETH3      1906
_DENVST3      1907
_MICHD        1908                    /* Section 7: Calculated Variables */
_LTASTH1      1909
_CASTHM1      1910
_ASTHMS1      1911
_DRDXAR2      1912
_PRACE2       1969-1970
_MRACE2       1971-1972
_HISPANC      1975
_RACE1        1976
_RACEG22      1977
_RACEGR4      1978
_RACEPR1      1979
_SEX          1980
_AGEG5YR      1981-1982
_AGE65YR      1983
_AGE80        1984-1985
_AGE_G        1986
HTIN4         1987-1989
HTM4          1990-1992
WTKG3         1993-1997
_BMI5         1998-2001
_BMI5CAT      2002
_RFBMI5       2003
_CHLDCNT      2004
_EDUCAG       2005
_INCOMG1      2006
_RFMAM22      2007                    /* Section 10: Calculated Variables */
_MAM5023      2008
_HADCOLN      2009                    /* Section 11: Calculated Variables */
_CLNSCP1      2010
_HADSIGM      2011
_SGMSCP1      2012
_SGMS101      2013
_RFBLDS5      2014
_STOLDN1      2015
_VIRCOL1      2016
_SBONTI1      2017
_CRCREC2      2018
_SMOKER3      2019                    /* Section 12: Calculated Variables */
_RFSMOK3      2020
_CURECI2      2021
_YRSSMOK      2022-2024               /* Section 13: Calculated Variables */
_PACKDAY      2025-2029
_PACKYRS      2030-2033
_YRSQUIT      2034-2035
_SMOKGRP      2036
_LCSREC       2037
DRNKANY6      2038                    /* Section 14: Calculated Variables */
DROCDY4_      2039-2041
_RFBING6      2042
_DRNKWK2      2043-2047
_RFDRHV8      2048
_FLSHOT7      2049                    /* Section 15: Calculated Variables */
_PNEUMO3      2050
_AIDTST4      2051                    /* Section 16: Calculated Variables */
;
*****************************************************************
* TO INCLUDE THE FORMAT ASSIGNEMT STATEMENT REMOVE THE ASTERISK *
* FROM THE BEGINNING OF THE FOLLOWING LINE                      *
*****************************************************************;
* %INCLUDE FORMATIN ;
*************************************************
* THIS SECTION CREATES LABELS FOR THE VARIABLES *
*************************************************;
Label
ACEADNED = 'DID AN ADULT MAKE SURE BASIC NEEDS WERE MET'
ACEADSAF = 'DID AN ADULT MAKE YOU FEEL SAFE AND PROTECTED'
ACEDEPRS = 'LIVE WITH ANYONE DEPRESSED, MENTALLY ILL, OR SUICIDAL?'
ACEDIVRC = 'WERE YOUR PARENTS DIVORCED/SEPERATED?'
ACEDRINK = 'LIVE WITH A PROBLEM DRINKER/ALCOHOLIC?'
ACEDRUGS = 'LIVE WITH ANYONE WHO USED ILLEGAL DRUGS OR ABUSED PRESCRIPTIONS?'
ACEHURT1 = 'HOW OFTEN DID A PARENT PHYSICALLY HURT YOU IN ANY WAY?'
ACEHVSEX = 'HOW OFTEN DID ANYONE EVER FORCE YOU TO HAVE SEX?'
ACEPRISN = 'LIVE WITH ANYONE WHO SERVED TIME IN PRISON OR JAIL?'
ACEPUNCH = 'HOW OFTEN DID YOUR PARENTS BEAT EACH OTHER UP?'
ACESWEAR = 'HOW OFTEN DID A PARENT SWEAR AT YOU?'
ACETOUCH = 'HOW OFTEN DID ANYONE EVER TOUCH YOU SEXUALLY?'
ACETTHEM = 'HOW OFTEN DID ANYONE MAKE YOU TOUCH THEM SEXUALLY?'
ADDEPEV3 = '(EVER TOLD) YOU HAD A DEPRESSIVE DISORDER'
ALCDAY4 = 'DAYS IN PAST 30 HAD ALCOHOLIC BEVERAGE'
ASBIADVC = 'OFFERED ADVICE ABOUT WHAT LEVEL OF DRINKING IS HARMFUL OR RISKY?'
ASBIALCH = 'ASKED DURING CHECKUP IF YOU DRINK ALCHOHOL'
ASBIBING = 'ASKED WHETHER YOU DRANK [5 FOR MEN /4 FOR WOMEN] OR MORE ALCOHOLIC DRINKS ON AN OCCASION?'
ASBIDRNK = 'ASKED IN PERSON OR BY FORM HOW MUCH YOU DRINK?'
ASBIRDUC = 'WERE YOU ADVISED TO REDUCE OR QUIT YOUR DRINKING?'
ASTHMA3 = 'EVER TOLD HAD ASTHMA'
ASTHNOW = 'STILL HAVE ASTHMA'
AVEDRNK3 = 'AVG ALCOHOLIC DRINKS PER DAY IN PAST 30'
BCPREFER = 'WHAT IS YOUR PREFERRED BIRTH CONTROL METHOD?'
BIRTHSEX = 'ARE YOU MALE OR FEMALE?'
BLDSTFIT = 'WAS TEST PART OF COLOGUARD TEST?'
BLIND = 'BLIND OR DIFFICULTY SEEING'
BRTHCNT4 = 'ARE YOU DOING ANYTHING TO KEEP FROM GETTING PREGNANT?'
CADULT1 = 'ARE YOU 18 YEARS OF AGE OR OLDER?'
CAGEG = 'FOUR LEVEL CHILD AGE'
CAREGIV1 = 'PROVIDED REGULAR CARE FOR FAMILY OR FRIEND'
CASTHDX2 = 'HLTH PRO EVER SAID CHILD HAS ASTHMA'
CASTHNO2 = 'CHILD STILL HAVE ASTHMA?'
CCLGHOUS = 'DO YOU LIVE IN COLLEGE HOUSING?'
CDASSIST = 'NEED ASSISTANCE WITH DAY-TO_DAY ACTIVITIES DUE TO CONFUSION OR MEMORY LOSS'
CDDISCUS = 'HAVE YOU DISCUSSED YOUR CONFUSION OR MEMORY LOSS WITH A HEALTH CARE PROFESSIONAL?'
CDHELP = 'WHEN YOU NEED HELP WITH DAY-TO-DAY ACTIVITIES ARE YOU ABLE TO GET IT'
CDHOUSE = 'GIVEN UP DAY-TO-DAY CHORES DUE TO CONFUSION OR MEMORY LOSS'
CDSOCIAL = 'DOES CONFUSION OR MEMORY LOSS INTERFERE WITH WORK OR SOCIAL ACTIVITIES'
CELLFON5 = 'IS THIS A CELL PHONE?'
CELLSEX1 = 'ARE YOU MALE OR FEMALE?'
CELPHON1 = 'CELLULAR TELEPHONE'
CERVSCRN = 'HAVE YOU EVER HAD A CERVICAL CANCER SCREENING TEST?'
CHCCOPD3 = 'EVER TOLD YOU HAD C.O.P.D. EMPHYSEMA OR CHRONIC BRONCHITIS?'
CHCKDNY2 = 'EVER TOLD YOU HAVE KIDNEY DISEASE?'
CHCOCNC1 = '(EVER TOLD) (YOU HAD) MELANOMA OR ANY OTHER TYPES OF CANCER?'
CHCSCNC1 = '(EVER TOLD) (YOU HAD) SKIN CANCER THAT IS NOT MELANOMA?'
CHECKUP1 = 'LENGTH OF TIME SINCE LAST ROUTINE CHECKUP'
CHILDREN = 'NUMBER OF CHILDREN IN HOUSEHOLD'
CHKHEMO3 = 'TIMES CHECKED FOR GLYCOSYLATED HEMOGLOBIN'
CIMEMLOS = 'HAVE YOU EXPERIENCED CONFUSION OR MEMORY LOSS THAT IS HAPPENING MORE OFTEN OR IS GETTING WORSE?'
CNCRAGE = 'AGE TOLD HAD CANCER'
CNCRDIFF = 'HOW MANY TYPES OF CANCER?'
CNCRTYP2 = 'TYPE OF CANCER'
COLGHOUS = 'DO YOU LIVE IN COLLEGE HOUSING?'
COLGSEX1 = 'ARE YOU MALE OR FEMALE?'
COLNCNCR = 'EVER HAD ANY OTHER KIND OF TEST FOR COLORECTAL CANCER'
COLNSIGM = 'EVER HAD A COLONOSCOPY, SIGMOIDOSCOPY, OR BOTH'
COLNTES1 = 'HOW LONG HAS IT BEEN SINCE YOU HAD COLONOSCOPY?'
COPDBRTH = 'DID YOU HAVE SHORTNESS OF BREATH?'
COPDBTST = 'HAVE YOU EVER BEEN GIVEN A BREATHING TEST?'
COPDCOGH = 'DID YOU HAVE A COUGH?'
COPDFLEM = 'DID YOU COUGH UP PHLEGM?'
COPDSMOK = 'HOW MANY YEARS HAVE YOU SMOKED TOBACCO PRODUCTS?'
COVIDFS1 = 'MONTH/YEAR OF FIRST COVID-19 VACCINATION'
COVIDNU1 = 'NUMBER OF COVID-19 VACCINATIONS RECEIVED'
COVIDPOS = 'HAVE YOU EVER BEEN TOLD YOU TESTED POSITIVE FOR COVID 19?'
COVIDPRM = 'WHICH WAS THE PRIMARY SYMPTOM THAT YOU EXPERIENCED?'
COVIDSE1 = 'MONTH/YEAR OF SECOND COVID-19 VACCINATION'
COVIDSMP = 'HAVE AN 3 MONTH OR LONGER COVID SYMPTOMS?'
COVIDVA1 = 'RECEIVED AT LEAST ONE COVID-19 VACCINATION'
CPDEMO1C = 'DO YOU HAVE A CELL PHONE FOR YOUR PERSONAL USE?'
CRGVALZD = 'DOES PERSON BEING CARED FOR HAVE ALZHEIMERS DISEASE?'
CRGVEXPT = 'DO YOU EXPECT TO HAVE A RELATIVE YOU WILL NEED TO PROVIDE CARE FOR?'
CRGVHOU1 = 'MANAGED HOUSEHOLD TASKS'
CRGVHRS1 = 'HOW MANY HOURS DO YOU PROVIDE CARE FOR PERSON?'
CRGVLNG1 = 'HOW LONG PROVIDED CARE FOR PERSON.'
CRGVPER1 = 'MANAGED PERSONAL CARE'
CRGVPRB3 = 'WHAT IS THE MAJOR HEALTH PROBLEM, ILLNESS, DISABILITY FOR CARE FOR PERSON?'
CRGVREL4 = 'RELATIONSHIP OF PERSON TO WHOM YOU ARE GIVING CARE?'
CRVCLCNC = 'TIME SINCE LAST CERVICAL CANCER SCREENING TEST'
CRVCLHPV = 'HAVE AN H.P.V. TEST AND RECENT CERVICAL CANCER SCREENING'
CRVCLPAP = 'HAVE A PAP TEST AND RECENT CERVICAL CANCER SCREENING'
CSRVCLIN = 'PARTICIPATE IN CLINICAL TRIAL AS PART OF CANCER TREATMENT?'
CSRVCTL2 = 'IS PAIN UNDER CONTROL?'
CSRVDEIN = 'EVER DENIED INSURANCE COVERAGE BECAUSE OF YOUR CANCER?'
CSRVDOC1 = 'WHAT TYPE OF DOCTOR PROVIDES MAJORITY OF YOUR CARE'
CSRVINSR = 'DID HEALTH INSURANCE PAY FOR ALL OF YOUR CANCER TREATMENT'
CSRVINST = 'INSTRUCTIONS WRITTEN OR PRINTED'
CSRVPAIN = 'CURRENTLY HAVE PHYSICAL PAIN FROM CANCER OR TREATMENT?'
CSRVRTRN = 'EVER RECEIVE INSTRUCTIONS FROM A DOCTOR FOR FOLLOW-UP CHECK-UPS'
CSRVSUM = 'DID YOU RECEIVE A SUMMARY OF CANCER TREATMENTS RECEIVED'
CSRVTRT3 = 'CURRENTLY RECEIVING TREATMENT FOR CANCER'
CSTATE1 = 'DO YOU CURRENTLY LIVE IN  ____(STATE)____?'
CTELENM1 = 'CORRECT TELEPHONE NUMBER?'
CTELNUM1 = 'CORRECT PHONE NUMBER?'
CVDCRHD4 = 'EVER DIAGNOSED WITH ANGINA OR CORONARY HEART DISEASE'
CVDINFR4 = 'EVER DIAGNOSED WITH HEART ATTACK'
CVDSTRK3 = 'EVER DIAGNOSED WITH A STROKE'
DEAF = 'ARE YOU DEAF OR DO YOU HAVE SERIOUS DIFFICULTY HEARING?'
DECIDE = 'DIFFICULTY CONCENTRATING OR REMEMBERING'
DIABAGE4 = 'AGE WHEN FIRST TOLD YOU HAD DIABETES'
DIABEDU1 = 'WHEN WAS THE LAST TIME YOU TOOK A COURSE OR CLASS IN HOW TO MANAGE YOUR DIABETES?'
DIABETE4 = '(EVER TOLD) YOU HAD DIABETES'
DIABEYE1 = 'WHEN WAS THE LAST TIME A THEY TOOK A PHOTO OF THE BACK OF YOUR EYE?'
DIABTYPE = 'WHAT TYPE OF DIABETES DO YOU HAVE?'
DIFFALON = 'DIFFICULTY DOING ERRANDS ALONE'
DIFFDRES = 'DIFFICULTY DRESSING OR BATHING'
DIFFWALK = 'DIFFICULTY WALKING OR CLIMBING STAIRS'
DISPCODE = 'FINAL DISPOSITION'
DRNK3GE5 = 'BINGE DRINKING'
DRNKANY6 = 'DRINK ANY ALCOHOLIC BEVERAGES IN PAST 30 DAYS'
DROCDY4_ = 'COMPUTED DRINK-OCCASIONS-PER-DAY'
ECIGNOW2 = 'DO YOU NOW USE E-CIGARETTES, OR VAPING PRODUCTS EVERY DAY, SOME DAYS, OR NOT AT ALL?'
EDUCA = 'EDUCATION LEVEL'
EMPLOY1 = 'EMPLOYMENT STATUS'
EMTSUPRT = 'HOW OFTEN GET EMOTIONAL SUPPORT NEEDED'
EXERANY2 = 'EXERCISE IN PAST 30 DAYS'
EYEEXAM1 = 'LAST EYE EXAM WHERE PUPILS WERE DILATED'
FEETSORE = 'EVER HAD FEET SORES OR IRRITATIONS LASTING MORE THAN FOUR WEEKS'
FIREARM5 = 'ANY FIREARMS IN HOME'
FLSHTMY3 = 'WHEN RECEIVED MOST RECENT SEASONAL FLU SHOT/SPRAY'
FLUSHOT7 = 'ADULT FLU SHOT/SPRAY PAST 12 MOS'
FMONTH = 'FILE MONTH'
FOODSTMP = 'DURING THE PAST 12 MONTHS HAVE YOU RECEIVED FOOD STAMPS'
GENHLTH = 'GENERAL HEALTH'
GUNLOAD = 'ANY FIREARMS LOADED'
HADHYST2 = 'HAD HYSTERECTOMY'
HADMAM = 'HAVE YOU EVER HAD A MAMMOGRAM'
HADSEX = 'HAVE YOU HAVE SEXUAL INTERCOURSE?'
HADSIGM4 = 'EVER HAD SIGMOIDOSCOPY/COLONOSCOPY'
HAVARTH4 = 'TOLD HAVE ARTHRITIS'
HAVECFS = 'STILL HAVE CHRONIC FATIGUE SYNDROME OR MYALGIC ENCEPHALOMYELITIS'
HEATTBCO = 'HAVE YOU HEARD OF HEATED TOBACCO PRODUCTS?'
HEIGHT3 = 'REPORTED HEIGHT IN FEET AND INCHES'
HHADULT = 'NUMBER OF ADULTS IN HOUSEHOLD'
HIVRISK5 = 'DO ANY HIGH RISK SITUATIONS APPLY'
HIVTST7 = 'EVER TESTED H.I.V.'
HIVTSTD3 = 'MONTH AND YEAR OF LAST HIV TEST'
HOWLONG = 'HOW LONG SINCE LAST MAMMOGRAM'
HPVADSHT = 'NUMBER OF HPV SHOTS RECEIVED'
HPVADVC4 = 'EVER HAD AN H.P.V. VACCINATION?'
HTIN4 = 'COMPUTED HEIGHT IN INCHES'
HTM4 = 'COMPUTED HEIGHT IN METERS'
IDATE = 'INTERVIEW DATE'
IDAY = 'INTERVIEW DAY'
IMFVPLA3 = 'WHERE DID YOU GET YOUR LAST FLU SHOT/VACCINE?'
IMONTH = 'INTERVIEW MONTH'
INCOME3 = 'INCOME LEVEL'
INSULIN1 = 'NOW TAKING INSULIN'
IYEAR = 'INTERVIEW YEAR'
LADULT1 = 'ARE YOU 18 YEARS OF AGE OR OLDER?'
LANDLINE = 'DO YOU ALSO HAVE A LANDLINE TELEPHONE?'
LANDSEX1 = 'ARE YOU MALE OR FEMALE?'
LASTDEN4 = 'LAST VISITED DENTIST OR DENTAL CLINIC'
LASTSIG4 = 'TIME SINCE LAST SIGMOIDOSCOPY/COLONOSCOPY'
LASTSMK2 = 'INTERVAL SINCE LAST SMOKED'
LCSCTSC1 = 'DID YOU HAVE A CT OR CAT SCAN?'
LCSCTWHN = 'WHEN DID YOU HAVE YOUR MOST RECENT CT OR CAT SCAN?'
LCSFIRST = 'HOW OLD WHEN YOU FIRST STARTED SMOKING?'
LCSLAST = 'HOW OLD WHEN YOU LAST SMOKED?'
LCSNUMCG = 'ON AVERAGE, HOW MANY CIGARETTES DO YOU SMOKE EACH DAY?'
LCSSCNCR = 'WERE ANY CT OR CAT SCANS DONE TO CHECK FOR LUNG CANCER?'
LOADULK2 = 'ANY LOADED FIREARMS ALSO UNLOCKED'
LSATISFY = 'SATISFACTION WITH LIFE'
MARIJAN1 = 'DURING THE PAST 30 DAYS, ON HOW MANY DAYS DID YOU USE MARIJUANA OR HASHISH?'
MARITAL = 'MARITAL STATUS'
MARJDAB = 'DID YOU DAB MARIJUANA OR CANNABIS?'
MARJEAT = 'DID YOU EAT MARIJUANA OR CANNABIS?'
MARJOTHR = 'DID YOU USE MARIJUANA OR CANNABIS SOME OTHER WAY?'
MARJSMOK = 'DID YOU SMOKE MARIJUANA OR CANNABIS?'
MARJVAPE = 'DID YOU VAPE MARIJUANA OR CANNABIS?'
MAXDRNKS = 'MOST DRINKS ON SINGLE OCCASION PAST 30 DAYS'
MEDCOST1 = 'COULD NOT AFFORD TO SEE DOCTOR'
MENTCIGS = 'DO YOU USUALLY SMOKE MENTHOL CIGARETTES?'
MENTECIG = 'DO YOU USUALLY USE MENTHOL E-CIGARETTES?'
MENTHLTH = 'NUMBER OF DAYS MENTAL HEALTH NOT GOOD'
MSCODE = 'METROPOLITAN STATUS CODE'
NOBCUSE8 = 'WHAT WAS MAIN REASON FOR NOT DOING ANYTHING TO KEEP YOU FROM GETTING PREGNANT?'
NUMADULT = 'NUMBER OF ADULTS IN HOUSEHOLD'
NUMHHOL4 = 'HOUSEHOLD LANDLINE TELEPHONES'
NUMMEN = 'NUMBER OF ADULT MEN IN HOUSEHOLD'
NUMPHON4 = 'RESIDENTIAL LANDLINE PHONES'
NUMWOMEN = 'NUMBER OF ADULT WOMEN IN HOUSEHOLD'
PCPSARS2 = 'WHAT WAS THE MAIN REASON YOU HAD THIS PSA TEST?'
PCSTALK1 = 'DID YOU TALK ABOUT THE ADVANTAGES OR DISADVANTAGES OF P.S.A. TEST'
PDIABTS1 = 'WHEN WAS YOUR LAST BLOOD TEST FOR HIGH BLOOD SUGAR?'
PERSDOC3 = 'HAVE PERSONAL HEALTH CARE PROVIDER?'
PFPPRVN4 = 'DID YOU DO ANYTHING TO KEEP FROM GETTING PREGNANT?'
PHYSHLTH = 'NUMBER OF DAYS PHYSICAL HEALTH NOT GOOD'
PNEUVAC4 = 'PNEUMONIA SHOT EVER'
POORHLTH = 'POOR PHYSICAL OR MENTAL HEALTH'
PREDIAB2 = 'EVER BEEN TOLD YOU HAVE PRE-DIABETES OR BORDERLINE DIABETES'
PREGNANT = 'PREGNANCY STATUS'
PRIMINSR = 'WHAT IS PRIMARY SOURCE OF HEALTH INSURANCE?'
PSASUGST = 'WHO FIRST SUGGESTED THIS PSA TEST?'
PSATEST1 = 'EVER HAD PSA TEST'
PSATIME1 = 'TIME SINCE MOST RECENT PSA TEST'
PVTRESD1 = 'PRIVATE RESIDENCE?'
PVTRESD3 = 'DO YOU LIVE IN A PRIVATE RESIDENCE?'
QSTLANG = 'LANGUAGE IDENTIFIER'
QSTVER = 'QUESTIONNAIRE VERSION IDENTIFIER'
RCSGEND1 = 'SEX OF CHILD'
RCSRLTN2 = 'RELATIONSHIP TO CHILD'
RCSXBRTH = 'CHILDS SEX AT BIRT'
RENTHOM1 = 'OWN OR RENT HOME'
RESPSLCT = 'RESPONDENT SELECTION'
RMVTETH4 = 'NUMBER OF PERMANENT TEETH REMOVED'
RRATWRK2 = 'HOW DO YOU FEEL YOU WERE TREATED AT WORK COMPARED TO PEOPLE OF OTHER RACES IN PAST 12 MONTHS?'
RRCLASS3 = 'HOW DO OTHER PEOPLE USUALLY CLASSIFY YOU IN THIS COUNTRY?'
RRCOGNT2 = 'HOW OFTEN DO YOU THINK ABOUT YOUR RACE?'
RRHCARE4 = 'WHEN SEEKING HEALTH CARE PAST 12 MONTHS, WAS EXPERIENCE WORSE, SAME, BETTER THAN PEOPLE OF OTHER RACES?'
RRPHYSM2 = 'TIMES PAST 30 DAYS FELT PHYSICAL SYMPTOMS BECAUSE OF TREATMENT DUE TO YOUR RACE'
RRTREAT = 'WERE YOU TREATED WORSE THAN, THE SAME, OR BETTER THAN PEOPLE OF OTHER RACES?'
SAFETIME = 'SAFE TIME TO TALK?'
SDHBILLS = 'WERE YOU NOT ABLE TO PAY YOUR BILLS?'
SDHEMPLY = 'HAVE YOU LOST EMPLOYMENT OR HAD HOURS REDUCED?'
SDHFOOD1 = 'HOW OFTEN DID THE FOOD THAT YOU BOUGHT NOT LAST, AND YOU DIDNT HAVE MONEY TO GET MORE?'
SDHISOLT = 'HOW OFTEN DO YOU FEEL SOCIALLY ISOLATED FROM OTHERS?'
SDHSTRE1 = 'HOW OFTEN HAVE YOU FELT THIS KIND OF STRESS?'
SDHTRNSP = 'HAS A LACK OF RELIABLE TRANSPORTATION KEPT YOU FROM APPOINTMENTS, MEETINGS, WORK, OR GETTING THINGS NEEDED'
SDHUTILS = 'WERE YOU NOT ABLE TO PAY UTILITY BILLS OR THREATENED TO LOSE SERVICE?'
SDNATES1 = 'HOW LONG SINCE YOU HAD STOOL DNA?'
SEQNO = 'ANNUAL SEQUENCE NUMBER'
SEXVAR = 'SEX OF RESPONDENT'
SHINGLE2 = 'HAVE YOU EVER HAD THE SHINGLES OR ZOSTER VACCINE?'
SIGMTES1 = 'HOW LONG HAS IT BEEN SINCE YOU HAD SIGMOIDOSCOPY?'
SLEPTIM1 = 'HOW MUCH TIME DO YOU SLEEP'
SMALSTOL = 'EVER HAD STOOL TEST?'
SMOKDAY2 = 'FREQUENCY OF DAYS NOW SMOKING'
SMOKE100 = 'SMOKED AT LEAST 100 CIGARETTES'
SOFEMALE = 'SEXUAL ORIENTATION'
SOMALE = 'SEXUAL ORIENTATION'
STATERE1 = 'RESIDENT OF STATE'
STOLTEST = 'HOW LONG SINCE YOU HAD STOOL TEST?'
STOOLDN2 = 'EVER HAD STOOL DNA TEST?'
STOPSMK2 = 'STOPPED SMOKING IN PAST 12 MONTHS'
TETANUS1 = 'RECEIVED TETANUS SHOT SINCE 2005?'
TOLDCFS = 'TOLD HAD CHRONIC FATIGUE SYNDROME OR MYALGIC ENCEPHALOMYELITIS'
TRNSGNDR = 'DO YOU CONSIDER YOURSELF TO BE TRANSGENDER?'
TYPCNTR9 = 'WHAT DID YOU DO TO KEEP YOU FROM GETTING PREGNANT?'
USEMRJN4 = 'DURING THE PAST 30 DAYS, HOW DID YOU PRIMARILY USE MARIJUANA?'
USENOW3 = 'USE OF SMOKELESS TOBACCO PRODUCTS'
VCLNTES2 = 'HOW LONG HAS IT BEEN SINCE YOU HAD VIRTUAL COLONOSCOPY?'
VETERAN3 = 'ARE YOU A VETERAN'
VIRCOLO1 = 'HAVE YOU EVER HAD A VIRTUAL COLONOSCOPY?'
WEIGHT2 = 'REPORTED WEIGHT IN POUNDS'
WHEREGET = 'WHERE DID YOU GET WHAT YOU USED TO PREVENT PREGNANCY?'
WORKCFS = 'HOW MANY HOURS A WEEK ARE YOU BEEN ABLE TO WORK'
WTKG3 = 'COMPUTED WEIGHT IN KILOGRAMS'
_AGE65YR = 'REPORTED AGE IN TWO AGE GROUPS CALCULATED VARIABLE'
_AGE80 = 'IMPUTED AGE VALUE COLLAPSED ABOVE 80'
_AGEG5YR = 'REPORTED AGE IN FIVE-YEAR AGE CATEGORIES CALCULATED VARIABLE'
_AGE_G = 'IMPUTED AGE IN SIX GROUPS'
_AIDTST4 = 'EVER BEEN TESTED FOR HIV CALCULATED VARIABLE'
_ALTETH3 = 'ADULTS AGED 65+ WHO HAVE HAD ALL THEIR NATURAL TEETH EXTRACTED'
_ASTHMS1 = 'COMPUTED ASTHMA STATUS'
_BMI5 = 'COMPUTED BODY MASS INDEX'
_BMI5CAT = 'COMPUTED BODY MASS INDEX CATEGORIES'
_CASTHM1 = 'CURRENT ASTHMA CALCULATED VARIABLE'
_CHISPNC = 'CHILD HISPANIC, LATINO/A, OR SPANISH ORIGIN CALCULATED VARIABLE'
_CHLDCNT = 'COMPUTED NUMBER OF CHILDREN IN HOUSEHOLD'
_CLLCPWT = 'FINAL CHILD WEIGHT: LAND-LINE AND CELL-PHONE DATA'
_CLNSCP1 = 'RESPONDENTS AGED 45-75 WHO HAVE HAD A COLONOSCOPY WITHIN THE PAST TEN YEARS'
_CPRACE2 = 'PREFERRED CHILD RACE CATEGORIES'
_CRACE2 = 'CHILD NON-HISPANIC RACE INCLUDING MULTIRACIAL'
_CRCREC2 = 'RESPONDENTS AGED 45-75 WHO HAVE FULLY MET THE USPSTF RECOMMENDATIONS'
_CURECI2 = 'CURRENT E-CIGARETTE USER CALCULATED VARIABLE'
_DENVST3 = 'ADULTS WHO HAVE VISITED A DENTIST, DENTAL HYGENIST OR DENTAL CLINIC WITHIN THE PAST YEAR'
_DRDXAR2 = 'RESPONDENTS DIAGNOSED WITH ARTHRITIS'
_DRNKWK2 = 'COMPUTED NUMBER OF DRINKS OF ALCOHOL BEVERAGES PER WEEK'
_DUALCOR = 'DUAL PHONE USE CORRECTION FACTOR'
_DUALUSE = 'DUAL PHONE USE CATEGORIES'
_EDUCAG = 'COMPUTED LEVEL OF EDUCATION COMPLETED CATEGORIES'
_EXTETH3 = 'RISK FACTOR FOR HAVING HAD PERMANENT TEETH EXTRACTED'
_FLSHOT7 = 'FLU SHOT CALCULATED VARIABLE'
_HADCOLN = 'HAD COLONOSCOPY CALCULATED VARIABLE'
_HADSIGM = 'HAD SIGMOIDOSCOPY CALCULATED VARIABLE'
_HCVU652 = 'RESPONDENTS AGED 18-64 WITH HEALTH INSURANCE'
_HISPANC = 'HISPANIC, LATINO/A, OR SPANISH ORIGIN CALCULATED VARIABLE'
_HLTHPLN = 'HAVE ANY HEALTH INSURANCE'
_IMPRACE = 'IMPUTED RACE/ETHNICITY VALUE'
_INCOMG1 = 'COMPUTED INCOME CATEGORIES'
_LCSREC = 'LUNG CANCER SCREENING RECOMMENDATION STATUS'
_LLCPWT = 'FINAL WEIGHT: LAND-LINE AND CELL-PHONE DATA'
_LLCPWT2 = 'TRUNCATED DESIGN WEIGHT USED IN ADULT COMBINED LAN  LINE AND CELL PHONE RAKING'
_LTASTH1 = 'LIFETIME ASTHMA CALCULATED VARIABLE'
_MAM5023 = 'WOMEN RESPONDENTS AGED 50-74 WHO HAVE HAD A MAMMOGRAM IN THE PAST TWO YEARS'
_MENT14D = 'COMPUTED MENTAL HEALTH STATUS'
_METSTAT = 'METROPOLITAN STATUS'
_MICHD = 'RESPONDENTS THAT HAVE EVER REPORTED HAVING CORONARY HEART DISEASE (CHD) OR MYOCARDIAL INFARCTION (MI)'
_MRACE2 = 'CALCULATED NON-HISPANIC RACE INCLUDING MULTIRACIAL'
_PACKDAY = 'NUMBER OF PACKS OF CIGARETTES SMOKED PER DAY'
_PACKYRS = 'YEARS SMOKED REPORTED PACKS PER DAY'
_PHYS14D = 'COMPUTED PHYSICAL HEALTH STATUS'
_PNEUMO3 = 'PNEUMONIA VACCINATION CALCULATED VARIABLE'
_PRACE2 = 'COMPUTED PREFERRED RACE'
_PSU = 'PRIMARY SAMPLING UNIT'
_RACE1 = 'COMPUTED RACE-ETHNICITY GROUPING'
_RACEG22 = 'COMPUTED NON-HISPANIC WHITES/ALL OTHERS RACE CATEGORIES RACE/ETHNIC GROUP CODES USED IN POST-STRATIFICATION.'
_RACEGR4 = 'COMPUTED FIVE LEVEL RACE/ETHNICITY CATEGORY.'
_RACEPR1 = 'COMPUTED RACE GROUPS USED FOR INTERNET PREVALENCE TABLES'
_RAWRAKE = 'RAW WEIGHTING FACTOR USED IN RAKING'
_RFBING6 = 'BINGE DRINKING CALCULATED VARIABLE'
_RFBLDS5 = 'RESPONDENTS AGED 45-75 WHO HAVE HAD A STOOL TEST WITHIN THE PAST YEAR'
_RFBMI5 = 'OVERWEIGHT OR OBESE CALCULATED VARIABLE'
_RFDRHV8 = 'HEAVY ALCOHOL CONSUMPTION  CALCULATED VARIABLE'
_RFHLTH = 'ADULTS WITH GOOD OR BETTER HEALTH'
_RFMAM22 = 'WOMEN RESPONDENTS AGED 40+ WHO HAVE HAD A MAMMOGRAM IN THE PAST TWO YEARS'
_RFSMOK3 = 'CURRENT SMOKING CALCULATED VARIABLE'
_SBONTI1 = 'RESPONDENTS AGED 45-75 WHO HAVE HAD A SIGMOIDOSCOPY WITHIN THE PAST TEN YEARS AND A BLOOD STOOL TEST IN THE PAST YEAR'
_SEX = 'CALCULATED SEX VARIABLE'
_SGMS101 = 'RESPONDENTS AGED 45-75 WHO HAVE HAD A SIGMOIDOSCOPY WITHIN THE PAST TEN YEARS'
_SGMSCP1 = 'RESPONDENTS AGED 45-75 WHO HAVE HAD A SIGMOIDOSCOPY WITHIN THE PAST FIVE YEARS'
_SMOKER3 = 'COMPUTED SMOKING STATUS'
_SMOKGRP = 'SMOKING GROUP'
_STATE = 'STATE FIPS CODE'
_STOLDN1 = 'RESPONDENTS AGED 45-75 WHO HAVE HAD A STOOL DNA TEST WITHIN THE PAST THREE YEARS'
_STRWT = 'STRATUM WEIGHT'
_STSTR = 'SAMPLE DESIGN STRATIFICATION VARIABLE'
_TOTINDA = 'LEISURE TIME PHYSICAL ACTIVITY CALCULATED VARIABLE'
_URBSTAT = 'URBAN/RURAL STATUS'
_VIRCOL1 = 'RESPONDENTS AGED 45-75 WHO HAVE HAD A VIRTUAL COLONOSCOPY WITHIN THE PAST FIVE YEARS'
_WT2RAKE = 'DESIGN WEIGHT USED IN RAKING'
_YRSQUIT = 'NUMBER OF YEARS SINCE QUIT SMOKING CIGARETTES'
_YRSSMOK = 'NUMBER OF YEARS SMOKED CIGARETTES'
;
RUN;
